checkdata.Problem (Data problem) — amici1

# `checkdata.Problem` (Data problem)

Problem(id, user, owner_type, owner_id, checker, message)

Master tables : checkdata.AllProblems (Data problems), checkdata.MyProblems (Data problems assigned to me), checkdata.Problems (Data problems)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Responsible (user) : The user responsible for fixing this problem.

- Database object (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Database object (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Checker (checker) : The Checker that reported this problem.

- Message (message) : The message text. This is a concatenation of all messages that were yielded by the checker.

- Name (name_column) : See `lino.modlib.checkdata.models.Problem.name_column`.

- (None) (navigation_panel) : See `lino.modlib.checkdata.models.Problem.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.checkdata.models.Problem.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
user | Responsible | The user responsible for fixing this problem.
owner_type | Database object (type) |
owner_id | Database object (object) |
checker | Checker | The Checker that reported this problem.
message | Message | The message text. This is a concatenation of all messages that were yielded by the checker.
owner | Database object |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |